==> xray_audit-1.0.0-rc1.tar.gz: xray_audit/src/Plugin/tasks/QueryGroup/XrayAuditQueryTaskParagraphsPlugin.php <==
<?php

namespace Drupal\xray_audit\Plugin\tasks\QueryGroup;

/**
 * Plugin implementation of queries_data_node.
 *
 * @XrayAuditTaskPlugin (
 *   id = "queries_data_paragraphs",
 *   label = @Translation("Data about paragraphs"),
 *   description = @Translation("Queries execute on database to get reports about paragraphs."),
 *   group = "queries_data",
 *   sort = 4,
 *   operations = {
 *      "paragraphs_count" = {
 *          "label" = "Paragraphs types and count",
 *          "description" = "Paragraphs types and count."
 *       },
 *      "paragraphs_count_by_language" = {
 *          "label" = "Paragraphs count grouped by language",
 *          "description" = "Paragraphs count grouped by language."
 *       },
 *    },
 *   dependencies = {"paragraphs"}
 * )
 */
class XrayAuditQueryTaskParagraphsPlugin extends XrayAuditQueryTaskPluginBase {

  /**
   * {@inheritdoc}
   */
  public function getDataOperationResult(string $operation = NULL) {
    switch ($operation) {
      case 'paragraphs_count':
        return $this->paragraphsTypes();

      case 'paragraphs_count_by_language':
        return $this->paragraphsItemsCountByLanguage();
    }
    return [];
  }

  /**
   * Paragraphs types.
   */
  public function paragraphsTypes() {
    $headerTable = ['id', 'label', 'count'];
    $resultTable = [];

    $storage_type =  $this->entityTypeManager->getStorage('paragraphs_type');
    $storage =  $this->entityTypeManager->getStorage('paragraph');
    $language_by_default = $this->languageManager->getDefaultLanguage()->getId();
    $alias_count = 'count';

    $result = $storage->getAggregateQuery()->aggregate('id', 'count', $language_by_default, $alias_count)->groupBy('type')->execute();

    // Prepare results.
    $result_processed = [];
    foreach ($result as $row) {
      $result_processed[$row['type']] = $row['count'];
    }

    $medias = $storage_type->loadMultiple();
    foreach ($medias as $key => $media) {
      $resultTable[] = [
        $key,
        $media->label(),
        ($result_processed[$key] ?? 0),
      ];
    }
    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];
  }

  /**
   * Paragraphs items count by language.
   */
  public function paragraphsItemsCountByLanguage() {

    $headerTable = ['label', 'type', 'langcode', 'total'];
    $resultTable = [];

    $storage_type =  $this->entityTypeManager->getStorage('paragraphs_type');
    $storage =  $this->entityTypeManager->getStorage('paragraph');
    $alias_count = 'count';

    // Get label of content types.
    $label = [];
    $types = $storage_type->loadMultiple();
    foreach ($types as $key => $type) {
      $label[$key] = $type->label();
    }

    $query =$storage->getAggregateQuery();
    $result = $query->aggregate('id', 'COUNT', null, $alias_count)->groupBy('langcode')->groupBy('type')->execute();

    foreach ($result as $row) {
      $resultTable[] = [
        'label' => $label[$row['type']],
        'id' => $row['type'],
        'langcode' => $row['langcode'],
        'total' => $row['count'] ?? 0,
      ];
    }

    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];

  }

  /**
   * {@inheritdoc}
   */
  public function buildDataPresentationForCli(array $data, string $operation = NULL) {
    // @todo Implement buildDataPresentationForCli() method.
    return '';
  }

}

==> xray_audit-1.1.1.tar.gz: xray_audit/src/Plugin/tasks/QueryGroup/XrayAuditQueryTaskParagraphsPlugin.php <==
<?php

namespace Drupal\xray_audit\Plugin\tasks\QueryGroup;

/**
 * Plugin implementation of queries_data_node.
 *
 * @XrayAuditTaskPlugin (
 *   id = "queries_data_paragraphs",
 *   label = @Translation("Data about paragraphs"),
 *   description = @Translation("Queries execute on database to get reports about paragraphs."),
 *   group = "queries_data",
 *   sort = 4,
 *   operations = {
 *      "paragraphs_count" = {
 *          "label" = "Paragraphs types and count",
 *          "description" = "Paragraphs types and count."
 *       },
 *      "paragraphs_count_by_language" = {
 *          "label" = "Paragraphs count grouped by language",
 *          "description" = "Paragraphs count grouped by language."
 *       },
 *    },
 *   dependencies = {"paragraphs"}
 * )
 */
class XrayAuditQueryTaskParagraphsPlugin extends XrayAuditQueryTaskPluginBase {

  /**
   * {@inheritdoc}
   */
  public function getDataOperationResult(string $operation = NULL) {
    switch ($operation) {
      case 'paragraphs_count':
        return $this->paragraphsTypes();

      case 'paragraphs_count_by_language':
        return $this->paragraphsItemsCountByLanguage();
    }
    return [];
  }

  /**
   * Get data of Paragraph types.
   *
   * @return array
   *   Render array.
   */
  public function paragraphsTypes() {
    $headerTable = [
      $this->t('id'),
      $this->t('label'),
      $this->t('count'),
    ];
    $resultTable = [];

    $storage_type = $this->entityTypeManager->getStorage('paragraphs_type');
    $storage = $this->entityTypeManager->getStorage('paragraph');
    $language_by_default = $this->languageManager->getDefaultLanguage()->getId();
    $alias_count = 'count';

    $result = $storage
      ->getAggregateQuery()
      ->accessCheck(FALSE)
      ->aggregate('id', 'count', $language_by_default, $alias_count)
      ->groupBy('type')
      ->execute();

    // Prepare results.
    $result_processed = [];
    foreach ($result as $row) {
      $result_processed[$row['type']] = $row['count'];
    }

    $medias = $storage_type->loadMultiple();
    foreach ($medias as $key => $media) {
      $resultTable[] = [
        $key,
        $media->label(),
        ($result_processed[$key] ?? 0),
      ];
    }
    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];
  }

  /**
   * Paragraphs items count by language.
   *
   * @return array
   *   Render array.
   */
  public function paragraphsItemsCountByLanguage() {

    $headerTable = [
      $this->t('label'),
      $this->t('type'),
      $this->t('langcode'),
      $this->t('total'),
    ];
    $resultTable = [];

    $storage_type = $this->entityTypeManager->getStorage('paragraphs_type');
    $storage = $this->entityTypeManager->getStorage('paragraph');
    $alias_count = 'count';

    // Get label of content types.
    $label = [];
    $types = $storage_type->loadMultiple();
    foreach ($types as $key => $type) {
      $label[$key] = $type->label();
    }

    $query = $storage->getAggregateQuery();
    $result = $query->accessCheck(FALSE)
      ->aggregate('id', 'COUNT', NULL, $alias_count)
      ->groupBy('langcode')
      ->groupBy('type')
      ->execute();

    foreach ($result as $row) {
      $resultTable[] = [
        'label' => $label[$row['type']],
        'id' => $row['type'],
        'langcode' => $row['langcode'],
        'total' => $row['count'] ?? 0,
      ];
    }

    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];

  }

}
